@@ -51,18 +51,22 @@ package com.openexchange.fileitem.impl;
 
 import static org.apache.commons.lang.StringUtils.isEmpty;
 import static org.apache.commons.lang.StringUtils.isNotEmpty;
+
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InvalidClassException;
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.List;
 import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.function.Consumer;
+
 import org.apache.commons.collections.BidiMap;
 import org.apache.commons.io.IOUtils;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import org.json.JSONObject;
+
 import com.openexchange.annotation.NonNull;
 import com.openexchange.annotation.Nullable;
 import com.openexchange.exception.OXException;
@@ -173,13 +177,30 @@ public class FileItemService implements IFileItemService {
         return m_database.hasCustomPropertyKey(groupId, key);
     }
 
-    // -------------------------------------------------------------------------
-
-    @Deprecated
+    /* (non-Javadoc)
+     * @see com.openexchange.imageconverter.api.IFileItemService#getUserData(java.lang.String)
+     */
     @Override
-    public IFileItem[] getByCustomQuery(String groupId, String customQuery, Object... returnValues) throws FileItemException {
-        // TODO (KA) Auto-generated method stub => remove after replaced by getSubGroupIdsBy
-        return null;
+    public JSONObject getUserData(@NonNull final String groupId) throws FileItemException {
+        if (isEmpty(groupId)) {
+            throw new FileItemException("Invalid groupId");
+        }
+
+        return m_database.getUserData(groupId);
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.imageconverter.api.IFileItemService#setUserData(java.lang.String, org.json.JSONObject)
+     */
+    @Override
+    public boolean setUserData(final String groupId, final JSONObject userData) throws FileItemException {
+        if (isEmpty(groupId)) {
+            throw new FileItemException("Invalid groupId");
+        }
+
+        return (null != userData) ?
+            m_database.setUserData(groupId, userData) :
+                false;
     }
 
     // -------------------------------------------------------------------------
@@ -321,7 +342,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getGroupLength(String groupId) throws FileItemException {
-        return m_database.getTotalLength(groupId, null, null);
+        return m_database.getGroupLength(groupId);
     }
 
     /* (non-Javadoc)
@@ -329,7 +350,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getGroupLength(String groupId, Properties properties) throws FileItemException {
-        return m_database.getTotalLength(groupId, null, properties);
+        return m_database.getGroupLength(groupId, null, properties);
     }
 
     /* (non-Javadoc)
@@ -337,7 +358,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getSubGroupLength(String groupId, String subGroupId) throws FileItemException {
-        return m_database.getTotalLength(groupId, subGroupId, null);
+        return m_database.getGroupLength(groupId, subGroupId, null);
     }
 
     /* (non-Javadoc)
@@ -345,7 +366,7 @@ public class FileItemService implements IFileItemService {
      */
     @Override
     public long getSubGroupLength(String groupId, String subGroupId, Properties properties) throws FileItemException {
-        return m_database.getTotalLength(groupId, subGroupId, properties);
+        return m_database.getGroupLength(groupId, subGroupId, properties);
     }
 
     // -------------------------------------------------------------------------
@@ -362,11 +383,12 @@ public class FileItemService implements IFileItemService {
             final String fileItemKey = fileItem.getKey();
 
             try {
-                ElementLocker.lock(fileItemKey);
-                final FileStoreData[] fileStoreDatas = m_database.deleteEntry(fileItem.getGroupId(), fileItem.getSubGroupId(), fileItem.getFileId());
+                final List<FileStoreData> deletedFileStoreDataList = new ArrayList<>();
 
-                if (FileItemUtils.isValid(fileStoreDatas))  {
-                    ret = (1 == m_fileStoreRemover.addFileStoreDatasToRemove(fileStoreDatas));
+                ElementLocker.lock(fileItemKey);
+
+                if (1 == m_database.deleteEntry(fileItem.getGroupId(), fileItem.getSubGroupId(), fileItem.getFileId(), deletedFileStoreDataList)) {
+                    ret = (m_fileStoreRemover.addFileStoreDatasToRemove(deletedFileStoreDataList) > 0);
                 }
             } finally {
                 ElementLocker.unlock(fileItemKey);
@@ -409,10 +431,11 @@ public class FileItemService implements IFileItemService {
         int ret = 0;
 
         if (isNotEmpty(groupId) && (null != properties) && (properties.size() > 0)) {
-            final FileStoreData[] fileStoreDatas = m_database.deleteByProperties(groupId, properties);
+            final List<FileStoreData> deletedFileStoreDataList = new ArrayList<>(8192);
+            final int deletedEntries = m_database.deleteByProperties(groupId, properties, deletedFileStoreDataList);
 
-            if (FileItemUtils.isValid(fileStoreDatas))  {
-                ret = m_fileStoreRemover.addFileStoreDatasToRemove(fileStoreDatas);
+            if (deletedEntries > 0)  {
+                ret = m_fileStoreRemover.addFileStoreDatasToRemove(deletedFileStoreDataList);
             }
         }
 
@@ -427,10 +450,11 @@ public class FileItemService implements IFileItemService {
         int ret = 0;
 
         if (FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupId)) {
-            final FileStoreData[] fileStoreDatas = m_database.deleteByGroupSubgroup(groupId, subGroupId);
+            final List<FileStoreData> deletedFileStoreDataList = new ArrayList<>(8192);
+            final int deletedEntries = m_database.deleteByGroupSubgroup(groupId, subGroupId, deletedFileStoreDataList);
 
-            if (FileItemUtils.isValid(fileStoreDatas))  {
-                ret = m_fileStoreRemover.addFileStoreDatasToRemove(fileStoreDatas);
+            if (deletedEntries > 0)  {
+                ret = m_fileStoreRemover.addFileStoreDatasToRemove(deletedFileStoreDataList);
             }
         }
 
@@ -445,14 +469,15 @@ public class FileItemService implements IFileItemService {
         int ret = 0;
 
         if (FileItemUtils.isValid(groupId) && FileItemUtils.isValid(subGroupIds)) {
+            final List<FileStoreData> deletedFileStoreDataList = new ArrayList<>(8192);
             final String[] targetSubGroupIds = Arrays.asList(subGroupIds).stream().
                                                    filter(FileItemUtils::isValid).
                                                    toArray(p -> new String[p]);
 
-            final FileStoreData[] fileStoreDatas = m_database.deleteByGroupSubgroups(groupId, targetSubGroupIds);
+            final int deletedEntries = m_database.deleteByGroupSubgroups(groupId, targetSubGroupIds, deletedFileStoreDataList);
 
-            if (FileItemUtils.isValid(fileStoreDatas))  {
-                ret = m_fileStoreRemover.addFileStoreDatasToRemove(fileStoreDatas);
+            if (deletedEntries > 0)  {
+                ret = m_fileStoreRemover.addFileStoreDatasToRemove(deletedFileStoreDataList);
             }
         }
 
@@ -468,10 +493,11 @@ public class FileItemService implements IFileItemService {
         int ret = 0;
 
         if (FileItemUtils.isValid(groupId)) {
-            final FileStoreData[] fileStoreDatas = m_database.deleteByGroupSubgroup(groupId, null);
+            final List<FileStoreData> deletedFileStoreDataList = new ArrayList<>(8192);
+            final int deletedEntries = m_database.deleteByGroupSubgroup(groupId, null, deletedFileStoreDataList);
 
-            if (FileItemUtils.isValid(fileStoreDatas))  {
-                ret = m_fileStoreRemover.addFileStoreDatasToRemove(fileStoreDatas);
+            if (deletedEntries > 0)  {
+                ret = m_fileStoreRemover.addFileStoreDatasToRemove(deletedFileStoreDataList);
             }
         }
 
@@ -669,17 +695,6 @@ public class FileItemService implements IFileItemService {
         return (FileItem) fileItem;
     }
 
-    /**
-     * @return
-     */
-    static Logger getLogger() {
-        return LOG;
-    }
-
-    // - Static members --------------------------------------------------------
-
-    final static Logger LOG = LoggerFactory.getLogger(FileItemService.class);
-
     // - Members ---------------------------------------------------------------
 
     protected FileItemDatabase m_database = null;
