@@ -67,6 +67,7 @@ import java.util.ListIterator;
 import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicLong;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
@@ -251,7 +252,28 @@ public class FileItemUtils {
      * @throws IOException
      */
     public static File createTempFile() throws IOException {
-        return File.createTempFile("oxfi", ".tmp", !IS_TERMINATED.get() ? TEMP_DIR : DEFAULT_TEMP_DIR);
+        final int maxAttempts = 8192;
+        final File tempDir = !IS_TERMINATED.get() ? TEMP_DIR : DEFAULT_TEMP_DIR;
+        final StringBuilder tempFilePrefixBuilder = new StringBuilder(256);
+
+        for (int i = 0; i < maxAttempts; ++i) {
+            tempFilePrefixBuilder.setLength(0);
+            tempFilePrefixBuilder.
+                append("oxfi-").
+                append(TEMP_COUNTER.incrementAndGet()).
+                append('-').
+                append(System.currentTimeMillis());
+
+            final File tmpFile = File.createTempFile(tempFilePrefixBuilder.toString(), ".tmp", tempDir);
+
+            if ((null != tmpFile) && tmpFile.exists()) {
+                return tmpFile;
+            }
+
+            Thread.yield();
+        }
+
+        return null;
     }
 
     /**
@@ -580,6 +602,8 @@ public class FileItemUtils {
 
     final private static File DEFAULT_TEMP_DIR = new File("/tmp");
 
+    final private static AtomicLong TEMP_COUNTER = new AtomicLong(0);
+
     private static File TEMP_DIR = new File("/tmp");
 
     private static File DATA_DIR = TEMP_DIR;
