@@ -55,9 +55,12 @@ import java.io.ObjectOutputStream;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.LinkedList;
+import java.util.List;
 import java.util.ListIterator;
 import java.util.concurrent.atomic.AtomicBoolean;
+
 import org.apache.commons.io.FileUtils;
+
 import com.google.common.base.Throwables;
 import com.openexchange.annotation.NonNull;
 import com.openexchange.imageconverter.api.FileItemException;
@@ -178,16 +181,11 @@ public class FileStoreRemover extends Thread {
     /**
      * @param fileStoreData
      */
-    public int addFileStoreDatasToRemove(@NonNull final FileStoreData[] fileStoreDatas) {
+    public int addFileStoreDatasToRemove(@NonNull final List<FileStoreData> fileStoreDataList) {
         synchronized (m_fileStoreDataList) {
             final int sizeBefore = m_fileStoreDataList.size();
 
-            for (FileStoreData curFileStoreData : fileStoreDatas) {
-                if (null != curFileStoreData) {
-                    m_fileStoreDataList.add(curFileStoreData);
-                }
-            }
-
+            m_fileStoreDataList.addAll(fileStoreDataList);
             m_fileStoreDataList.notify();
 
             return (m_fileStoreDataList.size() - sizeBefore);
