@@ -84,7 +84,7 @@ public class ImageConverterServerActivator extends HousekeepingActivator {
 
     @Override
     protected void startBundle() throws Exception {
-        LOG.info("starting bundle: " + SERVICE_NAME);
+        LOG.info("starting bundle: {}", SERVICE_NAME);
 
         try {
             final ConfigurationService configService = getService(ConfigurationService.class);
@@ -131,9 +131,9 @@ public class ImageConverterServerActivator extends HousekeepingActivator {
             m_applicationConfigurationTracker.open();
             openTrackers();
 
-            LOG.info("successfully started bundle: " + SERVICE_NAME);
+            LOG.info("successfully started bundle: {}", SERVICE_NAME);
         } catch (Throwable e) {
-            LOG.error("... starting bundle: " + SERVICE_NAME + " failed", e);
+            LOG.error("... starting bundle: {}", SERVICE_NAME + " failed", e);
             throw new RuntimeException(e);
         }
     }
@@ -142,7 +142,7 @@ public class ImageConverterServerActivator extends HousekeepingActivator {
 
     @Override
     protected void stopBundle() throws Exception {
-        LOG.info("stopping bundle: " + SERVICE_NAME);
+        LOG.info("stopping bundle: {}", SERVICE_NAME);
 
         closeTrackers();
         unregisterServices();
@@ -152,7 +152,7 @@ public class ImageConverterServerActivator extends HousekeepingActivator {
             m_imageConverterServerRest = null;
         }
 
-        LOG.info("successfully stopped bundle: " + SERVICE_NAME);
+        LOG.info("successfully stopped bundle: {}", SERVICE_NAME);
     }
 
     // - Static Members --------------------------------------------------------
