@@ -58,6 +58,8 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.lang.reflect.Method;
 import java.util.Arrays;
+import java.util.Collections;
+import java.util.List;
 import java.util.concurrent.atomic.AtomicBoolean;
 import javax.annotation.security.PermitAll;
 import javax.ws.rs.Consumes;
@@ -80,6 +82,7 @@ import org.apache.commons.lang.StringUtils;
 import org.glassfish.jersey.media.multipart.BodyPart;
 import org.glassfish.jersey.media.multipart.BodyPartEntity;
 import org.glassfish.jersey.media.multipart.MultiPart;
+import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.slf4j.Logger;
@@ -91,13 +94,18 @@ import com.openexchange.imageconverter.api.IImageConverter;
 import com.openexchange.imageconverter.api.IImageConverterMonitoring;
 import com.openexchange.imageconverter.api.IMetadata;
 import com.openexchange.imageconverter.api.ImageConverterException;
+import com.openexchange.imageconverter.api.ImageFormat;
 import com.openexchange.imageconverter.api.ImageServerUtil;
 import com.openexchange.imageconverter.api.MetadataImage;
+import com.openexchange.imageconverter.impl.ImageConverter;
+import com.openexchange.imageconverter.impl.ImageConverterMBean;
 import com.openexchange.imageconverter.impl.ImageConverterUtils;
+import com.openexchange.imageconverter.impl.ImageProcessor;
 import com.openexchange.rest.services.JAXRSService;
+import com.openexchange.rest.services.annotation.Role;
+import com.openexchange.rest.services.annotation.RoleAllowed;
 import com.openexchange.server.ServiceLookup;
 
-
 /**
  * {@link ImageConverterServerRest}
  *
@@ -106,7 +114,6 @@ import com.openexchange.server.ServiceLookup;
  */
 @Path("/imageconverter/")
 @Produces("application/json")
-@PermitAll
 public class ImageConverterServerRest extends JAXRSService {
 
     /**
@@ -130,19 +137,42 @@ public class ImageConverterServerRest extends JAXRSService {
      * @throws IOException
      */
     @GET
-    @Path("/status/")
     @Produces(MediaType.TEXT_HTML)
-    public String status(@QueryParam("metrics") @DefaultValue("false") String metrics) {
-        LOG.trace("IC WebService received #status request");
+    @PermitAll
+    public String root(@QueryParam("metrics") @DefaultValue("false") String metrics) {
+        LOG.trace("IC WebService received #/ request");
 
         return implCreateImageConverterServerHtmlPage(m_running.get() ?
             OX_IMAGECONVERTER_SERVER_DEFAULT_RESPONSE_TEXT :
                 OX_IMAGECONVERTER_SERVER_TERMINATED_RESPONSE_TEXT,
             StringUtils.equalsIgnoreCase(metrics, "true") ?
-                ImageConverterUtils.IC_MONITORING :
+                ImageConverterUtils.IC_MBEAN :
                     null);
     }
 
+    /**
+     * @param context
+     * @return
+     * @throws IOException
+     */
+    @GET
+    @Path("/status/")
+    @Produces("application/json")
+    @PermitAll
+    public JSONObject status(@QueryParam("metrics") @DefaultValue("false") String metrics) {
+        LOG.trace("IC WebService received #status request");
+
+        JSONObject ret = null;
+
+        try {
+            ret = implGetServerStatus(StringUtils.equalsIgnoreCase(metrics, "true"));
+        } catch (JSONException e) {
+            LOG.error("IC WebService JSON error in #status", e);
+        }
+
+        return ret;
+    }
+
     // - IImageConverter -------------------------------------------------------
 
     /**
@@ -154,6 +184,7 @@ public class ImageConverterServerRest extends JAXRSService {
     @GET
     @Path("/getImage/{imageKey}/{requestFormat}")
     @Produces(MediaType.MULTIPART_FORM_DATA)
+    @PermitAll
     public Response getImage(@PathParam("imageKey") String imageKey,
         @PathParam("requestFormat") String requestFormat,
         @QueryParam("context") @DefaultValue("") String context) {
@@ -185,10 +216,11 @@ public class ImageConverterServerRest extends JAXRSService {
     @GET
     @Path("/getMetadata/{imageKey}")
     @Produces(MediaType.MULTIPART_FORM_DATA)
+    @PermitAll
     public Response getMetadata(@PathParam("imageKey") String imageKey,
         @QueryParam("context") @DefaultValue("") String context) {
 
-    	LOG.trace("IC WebService received #getMetadata request: {}", imageKey);
+        LOG.trace("IC WebService received #getMetadata request: {}", imageKey);
 
         ResponseBuilder responseBuilder = null;
 
@@ -219,11 +251,12 @@ public class ImageConverterServerRest extends JAXRSService {
     @GET
     @Path("/getImageAndMetadata/{imageKey}/{requestFormat}")
     @Produces(MediaType.MULTIPART_FORM_DATA)
+    @PermitAll
     public Response getImageAndMetadata(@PathParam("imageKey") String imageKey,
         @PathParam("requestFormat") String requestFormat,
         @QueryParam("context") @DefaultValue("") String context) {
 
-    	LOG.trace("IC WebService received #getImageAndMetadata request: {} / {}", imageKey, requestFormat);
+        LOG.trace("IC WebService received #getImageAndMetadata request: {} / {}", imageKey, requestFormat);
 
         ResponseBuilder responseBuilder = null;
 
@@ -249,11 +282,12 @@ public class ImageConverterServerRest extends JAXRSService {
     @PUT
     @Path("/cacheImage/{imageKey}")
     @Consumes(MediaType.MULTIPART_FORM_DATA)
+    @PermitAll
     public Response cacheImage(MultiPart multiPart,
         @PathParam("imageKey") String imageKey,
         @QueryParam("context") @DefaultValue("") String context) {
 
-    	LOG.trace("IC WebService received #cacheImage request: {}", imageKey);
+        LOG.trace("IC WebService received #cacheImage request: {}", imageKey);
 
         ResponseBuilder responseBuilder = null;
 
@@ -287,6 +321,7 @@ public class ImageConverterServerRest extends JAXRSService {
     @Path("cacheAndGetImage/{imageKey}/{requestFormat}")
     @Consumes(MediaType.MULTIPART_FORM_DATA)
     @Produces(MediaType.MULTIPART_FORM_DATA)
+    @PermitAll
     public Response cacheAndGetImage(MultiPart multiPart,
         @PathParam("imageKey") String imageKey,
         @PathParam("requestFormat") String requestFormat,
@@ -327,6 +362,7 @@ public class ImageConverterServerRest extends JAXRSService {
     @Path("cacheAndGetImageAndMetadata/{imageKey}/{requestFormat}")
     @Consumes(MediaType.MULTIPART_FORM_DATA)
     @Produces(MediaType.MULTIPART_FORM_DATA)
+    @PermitAll
     public Response cacheAndGetImageAndMetadata(MultiPart multiPart,
         @PathParam("imageKey") String imageKey,
         @PathParam("requestFormat") String requestFormat,
@@ -361,6 +397,7 @@ public class ImageConverterServerRest extends JAXRSService {
      */
     @DELETE
     @Path("/clearImages")
+    @RoleAllowed(Role.BASIC_AUTHENTICATED)
     public Response clearImages(@QueryParam("context") @DefaultValue("") String context) {
         ResponseBuilder responseBuilder = null;
 
@@ -392,6 +429,7 @@ public class ImageConverterServerRest extends JAXRSService {
      */
     @DELETE
     @Path("/clearImagesByKey/{imageKey}")
+    @RoleAllowed(Role.BASIC_AUTHENTICATED)
     public Response clearImagesByKey(@PathParam("imageKey") String imageKey) {
         ResponseBuilder responseBuilder = null;
 
@@ -419,6 +457,7 @@ public class ImageConverterServerRest extends JAXRSService {
     @GET
     @Path("/getKeyCount")
     @Produces(MediaType.APPLICATION_JSON)
+    @PermitAll
     public JSONObject getKeyCount(@QueryParam("context") @DefaultValue("") String context) {
         JSONObject ret = new JSONObject();
 
@@ -428,7 +467,7 @@ public class ImageConverterServerRest extends JAXRSService {
             try {
                 ret.put("count", m_imageConverter.getKeyCount(context));
             } catch (Exception e) {
-            	LOG.error("IC WebService error in #getKeyCount", e);
+                LOG.error("IC WebService error in #getKeyCount", e);
             }
         } else {
             try {
@@ -449,6 +488,7 @@ public class ImageConverterServerRest extends JAXRSService {
     @GET
     @Path("/getKeys")
     @Produces(MediaType.APPLICATION_JSON)
+    @RoleAllowed(Role.BASIC_AUTHENTICATED)
     public JSONObject getKeys(@QueryParam("context") @DefaultValue("") String context) {
         JSONObject ret = new JSONObject();
 
@@ -458,13 +498,13 @@ public class ImageConverterServerRest extends JAXRSService {
             try {
                 ret.put("keys", Arrays.asList(m_imageConverter.getKeys(context)));
             } catch (Exception e) {
-            	LOG.error("IC WebService error in #getKeys", e);
+                LOG.error("IC WebService error in #getKeys", e);
             }
         } else {
             try {
                 ret = new JSONObject(implCreateJSONResponse(CODE_ERROR_TERMINATED, MESSAGE_ERROR_TERMINATED));
             } catch (Exception e) {
-            	LOG.error("IC WebService error in #getKeys", e);
+                LOG.error("IC WebService error in #getKeys", e);
             }
         }
 
@@ -540,6 +580,106 @@ public class ImageConverterServerRest extends JAXRSService {
         return htmlBuilder.append("</body></html>").toString();
     }
 
+    /**
+     * @return
+     * @throws JSONException
+     */
+    @NonNull private JSONObject implGetServerStatus(boolean includeMetrics) throws JSONException {
+        final JSONObject jsonStatus = new JSONObject();
+
+        // general
+        jsonStatus.put("name", "imageconverter");
+        jsonStatus.put("id", ImageServerUtil.IMAGE_SERVER_ID);
+        jsonStatus.put("api", OX_IMAGECONVERTER_SERVER_REMOTE_API_VERSION);
+        jsonStatus.put("apitext", "API: v" + OX_IMAGECONVERTER_SERVER_REMOTE_API_VERSION);
+        jsonStatus.put("status", m_running.get() ? "running" : "terminated");
+
+        // engine status
+        jsonStatus.put("engine", implGetEngineStatus());
+
+        // metrics on demand
+        final ImageConverterMBean imageConverterMBean = includeMetrics ? ImageConverterUtils.IC_MBEAN : null;
+
+        if (null != imageConverterMBean) {
+            jsonStatus.put("metrics", implGetMetrics(imageConverterMBean));
+        }
+
+        return jsonStatus;
+    }
+
+    /**
+     * @param <ImageProcessorStatus>
+     * @param imageConverterMBean
+     * @return
+     * @throws JSONException
+     */
+    private <ImageProcessorStatus> JSONObject implGetEngineStatus() throws JSONException  {
+        final JSONObject jsonEngineStatus = new JSONObject();
+
+        if (m_imageConverter instanceof ImageConverter) {
+            final ImageConverter imageConverter = (ImageConverter) m_imageConverter;
+
+            // image processor
+            final ImageProcessor.ImageProcessorStatus imageProcessorStatus = imageConverter.getImageProcessorStatus();
+            final JSONObject jsonImageProcessorStatus = new JSONObject();
+
+            jsonImageProcessorStatus.put("description", imageProcessorStatus.getProcessorDescription());
+            jsonImageProcessorStatus.put("available", imageProcessorStatus.isAvailable());
+
+            jsonEngineStatus.put("imageProcessor", jsonImageProcessorStatus);
+
+            // image formats
+            final ImageFormat[] usedImageFormats = imageConverter.getImageFormats();
+
+            if (null != usedImageFormats) {
+                jsonEngineStatus.put("imageFormats", new JSONArray(Arrays.asList(usedImageFormats)));
+            }
+        } else {
+            jsonEngineStatus.put("status", "n/a");
+        }
+
+        return jsonEngineStatus;
+    }
+
+    /**
+     * @param imageConverterMBean
+     * @return
+     * @throws JSONException
+     */
+    private JSONObject implGetMetrics(final ImageConverterMBean imageConverterMBean) throws JSONException  {
+        final List<Method> methodList = Arrays.asList(imageConverterMBean.getClass().getMethods());
+        final JSONObject jsonMetrics = new JSONObject();
+
+        Collections.sort(methodList, (one, other) -> one.getName().compareTo(other.getName()));
+
+        for (Method curMethod : methodList) {
+            if (null != curMethod) {
+                final String methodName = curMethod.getName();
+
+                if (isNotEmpty(methodName) && StringUtils.startsWithIgnoreCase(methodName, "get") && (curMethod.getParameterTypes().length == 0)) {
+                    final String metricsPropertyName = methodName.substring(3);
+                    final boolean isRatioMetric = metricsPropertyName.contains("Ratio");
+
+                    try {
+                        final String numberString = new StringBuilder().append(curMethod.invoke(imageConverterMBean)).toString();
+
+                        if (NumberUtils.isNumber(numberString)) {
+                            if (isRatioMetric) {
+                                jsonMetrics.put(metricsPropertyName, Double.parseDouble(numberString));
+                            } else {
+                                jsonMetrics.put(metricsPropertyName, Long.parseLong(numberString));
+                            }
+                        }
+                    } catch (@SuppressWarnings("unused") Exception e) {
+                        //
+                    }
+                }
+            }
+        }
+
+        return jsonMetrics;
+    }
+
     /**
      * @param inputStm
      * @return
@@ -643,7 +783,7 @@ public class ImageConverterServerRest extends JAXRSService {
             responseObject.put("code", code);
             responseObject.put("message", isNotEmpty(message) ? message : MESSAGE_SUCCESS);
         } catch (JSONException e) {
-        	LOG.error(e.getMessage(), e);
+            LOG.error(e.getMessage(), e);
         }
 
         return responseObject.toString();
