@@ -68,6 +68,7 @@ import org.apache.commons.io.FileUtils;
 import com.openexchange.annotation.NonNull;
 import com.openexchange.annotation.Nullable;
 import com.openexchange.imageconverter.api.FileItemException;
+import com.openexchange.imageconverter.api.IFileItemService;
 import com.openexchange.imageconverter.api.IFileItemWriteAccess;
 import com.openexchange.imageconverter.api.IMetadata;
 import com.openexchange.imageconverter.api.IMetadataReader;
@@ -100,8 +101,7 @@ class ImageConverterJob implements Runnable, Closeable {
         @NonNull final InputStream srcImageStm,
         @NonNull final List<ImageFormat> imageFormats,
         @NonNull ImageConverterQueue queue,
-        @Nullable final String context,
-        @Nullable final IMetadata metadata ) throws ImageConverterException {
+        @Nullable final String context) throws ImageConverterException {
 
         super();
 
@@ -118,10 +118,8 @@ class ImageConverterJob implements Runnable, Closeable {
                 throw new IOException("IC ConversionJob creation of job not possible due to missing or empty input file: " + imageKey);
             }
 
-            // assign given metadata or read metadata from input file
-            m_imageMetadata = (null != metadata) ?
-                metadata :
-                    implCreateKeyMetadata(queue.getMetadataReader(), m_imageKey, m_inputFile, m_context);
+            // read metadata from input file
+            m_imageMetadata = implCreateKeyMetadata(queue.getMetadataReader(), m_imageKey, m_inputFile, m_context);
 
             if (null == m_imageMetadata) {
                 throw new MetadataException("IC ConversionJob error while trying to read image metadata from input file: " + imageKey);
@@ -158,7 +156,7 @@ class ImageConverterJob implements Runnable, Closeable {
         ImageFormat curTargetFormat = null;
 
         if (trace) {
-            LOG.trace("IC ConversionJob run started: " + m_imageKey);
+            LOG.trace("IC ConversionJob run started: {}", m_imageKey);
         }
 
         try {
@@ -188,7 +186,7 @@ class ImageConverterJob implements Runnable, Closeable {
             ImageConverterUtils.IC_MONITOR.incrementProcessedKeys(m_processingTime);
 
             if (trace) {
-                LOG.trace("IC ConversionJob run finished: " + m_imageKey);
+                LOG.trace("IC ConversionJob run finished: {}", m_imageKey);
             }
         }
     }
@@ -228,26 +226,39 @@ class ImageConverterJob implements Runnable, Closeable {
      * @return
      * @throws ImageConverterException
      */
-    protected void implProcessKey(@NonNull final ImageFormat targetFormat, final boolean isAsync) throws ImageConverterException {
+    protected boolean implProcessKey(@NonNull final ImageFormat targetFormat, final boolean isAsync) throws ImageConverterException {
         ImageFormat processingFormat = m_formatsToProcess.get(targetFormat);
         final long subProcessingStartTimeMillis = System.currentTimeMillis();
+        boolean ret = false;
 
         if (null == processingFormat) {
             // check first, if we need to create the reference format entry for the requested ScaleType
             final ImageFormat referenceFormat = m_referenceFormatMap.get(targetFormat.getScaleType());
 
             if ((null != referenceFormat) && (null != (processingFormat = m_formatsToProcess.get(referenceFormat)))) {
-                implCreateThumbnail(m_imageKey, m_inputFile, m_imageMetadata, referenceFormat, processingFormat, m_context, isAsync);
-                m_formatsToProcess.remove(referenceFormat);
+                ret = implCreateThumbnail(m_imageKey, m_inputFile, m_imageMetadata, referenceFormat, processingFormat, m_context, isAsync);
+
+                if (ret) {
+                    m_formatsToProcess.remove(referenceFormat);
+                }
+            } else {
+                ret = true;
             }
 
-            implCreatReferenceThumbnail(m_imageKey, m_imageMetadata, targetFormat, referenceFormat, m_context, isAsync);
+            if (ret) {
+                implCreatReferenceThumbnail(m_imageKey, m_imageMetadata, targetFormat, referenceFormat, m_context, isAsync);
+            }
         } else {
-            implCreateThumbnail(m_imageKey, m_inputFile, m_imageMetadata, targetFormat, processingFormat, m_context, isAsync);
+            ret = implCreateThumbnail(m_imageKey, m_inputFile, m_imageMetadata, targetFormat, processingFormat, m_context, isAsync);
+        }
+
+        if (ret) {
+            m_formatsToProcess.remove(targetFormat);
         }
 
-        m_formatsToProcess.remove(targetFormat);
         m_processingTime += (System.currentTimeMillis() - subProcessingStartTimeMillis);
+
+        return ret;
     }
 
     /**
@@ -269,12 +280,16 @@ class ImageConverterJob implements Runnable, Closeable {
                 throw new ImageConverterException("IC ConversionJob is not able to parse requested image format: " + requestFormat);
             }
 
+            boolean isAvailable = !m_formatsToProcess.containsKey(requestTargetFormat);
+
             // no need to do anything, if requested format has already been processed
-            if (m_formatsToProcess.containsKey(requestTargetFormat)) {
-                implProcessKey(requestTargetFormat, false);
+            if (!isAvailable) {
+                isAvailable = implProcessKey(requestTargetFormat, false);
             }
 
-            ret = new MetadataImage(ImageConverterUtils.readImageByTargetFormat(m_queue.getFileItemService(), m_imageKey, requestTargetFormat), m_imageMetadata);
+            if (isAvailable) {
+                ret = new MetadataImage(ImageConverterUtils.readImageByTargetFormat(m_queue.getFileItemService(), m_imageKey, requestTargetFormat), m_imageMetadata);
+            }
         } catch (Exception e) {
             throw new ImageConverterException(ImageConverterUtils.STR_BUILDER().
                 append(m_imageKey).
@@ -337,7 +352,7 @@ class ImageConverterJob implements Runnable, Closeable {
      * @return
      * @throws MetadataException
      */
-    protected IMetadata implCreateKeyMetadata(@NonNull final IMetadataReader metadataReader, @NonNull final String imageKey, @NonNull final File inputFile, @Nullable final String context) throws MetadataException {
+    private IMetadata implCreateKeyMetadata(@NonNull final IMetadataReader metadataReader, @NonNull final String imageKey, @NonNull final File inputFile, @Nullable final String context) throws MetadataException {
         IMetadata ret = metadataReader.readMetadata(inputFile);
 
         if (null != ret) {
@@ -379,7 +394,7 @@ class ImageConverterJob implements Runnable, Closeable {
      * @param referencePropertyValue
      * @throws FileItemException
      */
-    protected static void implSetProperties(@NonNull final IFileItemWriteAccess writeAccess, @Nullable final String context, @Nullable final String referencePropertyValue) throws FileItemException {
+    private static void implSetProperties(@NonNull final IFileItemWriteAccess writeAccess, @Nullable final String context, @Nullable final String referencePropertyValue) throws FileItemException {
         if (null != context) {
             writeAccess.setKeyValue(ImageConverterUtils.IMAGECONVERTER_KEY_CONTEXT, context);
         }
@@ -394,59 +409,60 @@ class ImageConverterJob implements Runnable, Closeable {
      * @param processingFormat
      * @throws ImageConverterException
      */
-    protected void implCreateThumbnail(@NonNull final String imageKey, @NonNull final File inputFile,
+    private boolean implCreateThumbnail(@NonNull final String imageKey, @NonNull final File inputFile,
         @NonNull final IMetadata imageMetadata,
         @NonNull final ImageFormat targetFormat,
         @NonNull final ImageFormat processingFormat,
         @Nullable final String context,
         final boolean isAsync) throws ImageConverterException {
 
+        final IFileItemService fileItemService = m_queue.getFileItemService();
         final String targetFormatStr = targetFormat.getFormatString();
         final ImageFormat usedProcessingFormat = (null != processingFormat) ? processingFormat : targetFormat;
-        boolean succeeded = false;
+        boolean ret = false;
 
-        try (final IFileItemWriteAccess fileWriteAccess =
-            m_queue.getFileItemService().getWriteAccess(ImageConverterUtils.IMAGECONVERTER_GROUPID, imageKey, targetFormatStr)) {
+        try (final IFileItemWriteAccess fileWriteAccess = fileItemService.getWriteAccess(ImageConverterUtils.IMAGECONVERTER_GROUPID, imageKey, targetFormatStr)) {
 
             if ((null != fileWriteAccess) && m_queue.getImageProcessor().scale(inputFile, fileWriteAccess.getOutputFile(), usedProcessingFormat)) {
                 implSetProperties(fileWriteAccess, context, null);
-                succeeded = true;
+                ret = true;
             }
 
             if (LOG.isTraceEnabled()) {
                 final Dimension imageDimension = imageMetadata.getImageDimension();
                 final String imageFormatShortName = imageMetadata.getImageFormatName();
+                final StringBuilder traceMsgBuilder = ImageConverterUtils.STR_BUILDER().
+                    append("IC image processor ").
+                    append(isAsync ? "a" : "").append("synchronously").
+                    append(ret ? " scaled image to create " : " could not scale image to create ").
+                    append(imageFormatShortName).append(" thumbnail for ");
 
                 LOG.trace(ImageConverterUtils.STR_BUILDER().
-                    append("IC ").append(isAsync ? "a" : "").
-                    append("synchronously created ").append(imageFormatShortName).append(" thumbnail for ").
-                    append("[").append(imageDimension.width).append('x').append(imageDimension.height).append("] ").
-                    append(imageFormatShortName).append(" image: ").
-                    append(imageKey).append(" / ").append(targetFormatStr).
-                    append(" (Used physical format: ").append(usedProcessingFormat.getFormatString()).append(')').toString());
+                    append(traceMsgBuilder).
+                    append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, usedProcessingFormat.getFormatString())).toString());
             }
-        } catch (Exception e) {
+        } catch (@SuppressWarnings("unused") Exception e) {
             final Dimension imageDimension = imageMetadata.getImageDimension();
             final String imageFormatShortName = imageMetadata.getImageFormatName();
 
             LOG.error(ImageConverterUtils.STR_BUILDER().
                 append("IC error while ").append(isAsync ? "a" : "").
                 append("synchronously creating ").append(imageFormatShortName).append(" thumbnail for ").
-                append("[").append(imageDimension.width).append('x').append(imageDimension.height).append("] image: ").
-                append(imageKey).append(" / ").append(targetFormatStr).
-                append(" (Used physical format: ").append(usedProcessingFormat.getFormatString()).append(')').toString(), e);
+                append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, usedProcessingFormat.getFormatString())).toString());
         } finally {
-            if (!succeeded) {
+            if (!ret) {
                 implRemoveFile(imageKey, targetFormatStr);
             }
         }
+
+        return ret;
     }
 
     /**
      * @param targetFormat
      * @throws ImageConverterException
      */
-    protected void implCreatReferenceThumbnail(@NonNull final String imageKey,
+    private void implCreatReferenceThumbnail(@NonNull final String imageKey,
         @NonNull final IMetadata imageMetadata,
         @NonNull final ImageFormat targetFormat,
         @NonNull final ImageFormat referenceFormat,
@@ -471,10 +487,7 @@ class ImageConverterJob implements Runnable, Closeable {
                 LOG.trace(ImageConverterUtils.STR_BUILDER().
                     append("IC ").append(isAsync ? "a" : "").
                     append("synchronously created reference entry for ").
-                    append("[").append(imageDimension.width).append('x').append(imageDimension.height).append("] ").
-                    append(imageFormatShortName).append(" image: ").
-                    append(imageKey).append(" / ").append(targetFormatStr).
-                    append(" (Used reference format: ").append(referenceFormatStr).append(')').toString());
+                    append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, referenceFormatStr)).toString());
             }
         } catch (Exception e) {
             implRemoveFile(imageKey, targetFormatStr);
@@ -484,11 +497,8 @@ class ImageConverterJob implements Runnable, Closeable {
 
             LOG.error(ImageConverterUtils.STR_BUILDER().
                 append("IC error while ").append(isAsync ? "a" : "").
-                append("synchronously creating reference entry for: ").
-                append("[").append(imageDimension.width).append('x').append(imageDimension.height).append("] ").
-                append(imageFormatShortName).append(" image: ").
-                append(imageKey).append(" / ").append(targetFormatStr).
-                append(" (Used reference format: ").append(referenceFormatStr).append(')').toString(), e);
+                append("synchronously creating reference entry for ").
+                append(implGetImageInformationString(imageKey, imageDimension, imageFormatShortName, targetFormatStr, referenceFormatStr)).toString());
         }
     }
 
@@ -496,7 +506,7 @@ class ImageConverterJob implements Runnable, Closeable {
      * @param imageKey
      * @param fileId
      */
-    protected void implRemoveFile(@NonNull final String imageKey, @NonNull final String fileName) {
+    private void implRemoveFile(@NonNull final String imageKey, @NonNull final String fileName) {
         try {
             m_queue.getFileItemService().remove(ImageConverterUtils.IMAGECONVERTER_GROUPID, imageKey, fileName);
         } catch (FileItemException e) {
@@ -513,7 +523,7 @@ class ImageConverterJob implements Runnable, Closeable {
      * @param imageFormats
      * @return
      */
-    protected static List<ImageFormat> implCreateImageFormatList(@NonNull final IMetadata metadata, @NonNull final List<ImageFormat> imageFormats) {
+    private static List<ImageFormat> implCreateImageFormatList(@NonNull final IMetadata metadata, @NonNull final List<ImageFormat> imageFormats) {
         final List<ImageFormat> ret = new ArrayList<>();
         final String imageFormatShortName = metadata.getImageFormatName();
         final boolean isAnimated = imageFormatShortName.startsWith("gif");
@@ -552,13 +562,34 @@ class ImageConverterJob implements Runnable, Closeable {
             targetImageFormat.setScaleType(curFormat.getScaleType());
             targetImageFormat.setShrinkOnly(curFormat.isShrinkOnly());
 
-
             ret.add(targetImageFormat);
         }
 
         return ret;
     }
 
+    /**
+     * @param imageKey
+     * @param imageDimension
+     * @param imageFormatShortName
+     * @param targetFormatStr
+     * @param usedProcessingFormat
+     * @return
+     */
+    private StringBuilder implGetImageInformationString(
+        final String imageKey,
+        final Dimension imageDimension,
+        final String imageFormatShortName,
+        final String targetFormatStr,
+        final String usedProcessingFormatStr) {
+
+        return ImageConverterUtils.STR_BUILDER().
+            append("[").append(imageDimension.width).append('x').append(imageDimension.height).append("] ").
+            append(imageFormatShortName).append(" image: ").
+            append(imageKey).append(" / ").append(targetFormatStr).
+            append(" (Used physical format: ").append(usedProcessingFormatStr).append(')');
+    }
+
     // - Members ---------------------------------------------------------------
 
     final private String m_imageKey;
