@@ -84,6 +84,7 @@ import com.openexchange.imageconverter.api.ImageConverterPriority;
 import com.openexchange.imageconverter.api.ImageFormat;
 import com.openexchange.imageconverter.api.MetadataException;
 import com.openexchange.imageconverter.api.MetadataImage;
+import com.openexchange.imageconverter.impl.ImageProcessor.ImageProcessorStatus;
 
 /**
  * {@link ImageConverterQueue}
@@ -127,8 +128,8 @@ class ImageConverterQueue extends Thread {
                                 try {
                                     curJob.run();
                                 } finally {
+                                    // close job, imageKey will be removed from processingMap as well
                                     implCloseJob(curJob, !isRunning());
-                                    m_processingMap.remove(imageKey);
 
                                     ElementLocker.unlock(imageKey, ElementLock.UnlockMode.END_PROCESSING);
                                 }
@@ -203,7 +204,8 @@ class ImageConverterQueue extends Thread {
                     if ((null != curJob) && ((null == predicateOrAll) || predicateOrAll.test(curJob.getImageKey()))) {
                         ret = true;
                         iter.remove();
-                        m_processingMap.remove(curJob.getImageKey());
+
+                        // close job, imageKey will be removed from processingMap as well
                         implCloseJob(curJob, true);
                     }
                 }
@@ -296,7 +298,10 @@ class ImageConverterQueue extends Thread {
 
         // create an ordered BidiMap to map ImageFormats to image format strings and vice versa
         m_imageFormats = Arrays.asList(m_imageConverter.getImageFormats());
-        m_imageProcessor = new ImageProcessor(ImageConverterConfig.IMAGECONVERTER_SEARCHPATH, ImageConverterConfig.IMAGECONVERTER_USE_GRAPHICSMAGICK);
+        m_imageProcessor = new ImageProcessor(
+            ImageConverterConfig.IMAGECONVERTER_SEARCHPATH,
+            ImageConverterConfig.IMAGECONVERTER_USE_GRAPHICSMAGICK,
+            ImageConverterConfig.IMAGECONVERTER_IMAGE_USERCOMMENT);
 
         for (final ImageConverterPriority curPriority : ImageConverterPriority.values()) {
             m_queuesImpl.put(curPriority, new ImageConverterQueueImpl(curPriority));
@@ -353,13 +358,13 @@ class ImageConverterQueue extends Thread {
                         queueEntry.getPriority());
 
                     if (!m_executor.addJob(job)) {
-                        m_processingMap.remove(job.getImageKey());
+                        // close job, imageKey will be removed from processingMap as well
                         implCloseJob(job, true);
                     }
                 }
             } catch (@SuppressWarnings("unused") Exception e) {
                 if (trace) {
-                    LOG.trace("IC queue received exception while taking next job from queue and forwarding to executor: " + Throwables.getRootCause(e));
+                    LOG.trace("IC queue received exception while taking next job from queue and forwarding to executor: {}", Throwables.getRootCause(e));
                 }
             }
         }
@@ -371,6 +376,13 @@ class ImageConverterQueue extends Thread {
 
     // - Public API ------------------------------------------------------------
 
+    /**
+     * @return
+     */
+    public ImageProcessorStatus getImageProcessorStatus() {
+        return m_imageProcessor.getStatus();
+    }
+
     /**
      * @return
      */
@@ -431,7 +443,7 @@ class ImageConverterQueue extends Thread {
         try {
             ret = getMetadataImage(imageKey, requestFormat);
         } catch (ImageConverterException e) {
-            LOG.trace("IC not able to read MetadataImage", e);
+            LOG.trace("IC not yet able to read MetadataImage, waiting for processed key first", e);
         }
 
         if (null == ret) {
@@ -477,7 +489,7 @@ class ImageConverterQueue extends Thread {
                     // job is asynchronously processed afterwards
                     if (null != queueEntry) {
                         if (trace) {
-                            LOG.trace("IC queue synchronously processes job in user request: " + imageKey);
+                            LOG.trace("IC queue synchronously processes job in user request: {}", imageKey);
                         }
 
                         // change priority for already scheduled job
@@ -494,7 +506,7 @@ class ImageConverterQueue extends Thread {
                     // image key is available in general, but not queued anymore =>
                     // wait until outstanding job has been processed completely, if necessary
                     if (trace) {
-                        LOG.trace("IC queue gets image/waits for finish of asynchronous job processing in user request: " + imageKey);
+                        LOG.trace("IC queue gets image/waits for finish of asynchronous job processing in user request: {}", imageKey);
                     }
 
                     ElementLocker.lock(imageKey, ElementLock.LockMode.WAIT_IF_PROCESSED);
@@ -625,12 +637,12 @@ class ImageConverterQueue extends Thread {
 
                 if (null != openJobList) {
                     if (trace) {
-                        LOG.trace("IC is closing already queued entries in shutdown: " + openJobList.size());
+                        LOG.trace("IC is closing already queued entries in shutdown: {}", openJobList.size());
                     }
 
                     // cleanup/close of all pending Runnables
                     openJobList.forEach((curJob) -> {
-                        m_processingMap.remove(((ImageConverterJob) curJob).getImageKey());
+                        // close job, imageKey will be removed from processingMap as well
                         implCloseJob(((ImageConverterJob) curJob), true);
                     });
                 }
@@ -641,7 +653,7 @@ class ImageConverterQueue extends Thread {
                 Thread.currentThread().interrupt();
             }
 
-            LOG.trace("IC queue shutdown open Runnable count after shutdown: {}" + m_processingMap.size());
+            LOG.trace("IC queue shutdown open Runnable count after shutdown: {}{}", m_processingMap.size());
             LOG.trace("IC queue shutdown finished in {}ms", Long.valueOf((System.currentTimeMillis() - shutdownStartTimeMillis)));
         }
     }
@@ -664,36 +676,61 @@ class ImageConverterQueue extends Thread {
         @Nullable final String context,
         @Nullable final ImageConverterPriority priority) throws ImageConverterException {
 
-        ImageConverterJob job = null;
-        MetadataImage ret = null;
+        // we need to ensure that no other job with the same
+        // imageKey is currently running => wait until processed
+        ElementLocker.lock(imageKey, ElementLock.LockMode.WAIT_IF_PROCESSED);
 
-        // wait for a possible other thread, currently processing
-        // the given imageKey and finally start a new processing cycle
-        ElementLocker.lock(imageKey, ElementLock.LockMode.BEGIN_PROCESSING);
+        try {
+            // begin processing out of the lock state of the previous lock
+            ElementLocker.lock(imageKey, ElementLock.LockMode.BEGIN_PROCESSING);
+        } finally {
+            // unlock the first waiting lock now, the BEGIN_PROCESSING lock
+            // is still active and will be unlocked temporarily after
+            // queuing and initial request processing;
+            // final END_PROCESSING unlock will happen in an async. way
+            ElementLocker.unlock(imageKey, ElementLock.UnlockMode.STANDARD);
+        }
 
         if (m_processingMap.containsKey(imageKey)) {
             LOG.warn("IC queue processing map already contains imageKey while start queueing: {}", imageKey);
         }
 
+        ImageConverterJob job = null;
+        MetadataImage ret = null;
+        boolean errorOccured = false;
+
         try {
-            job = new ImageConverterJob(imageKey, srcImageStm, m_imageFormats, this, context, null);
+            job = new ImageConverterJob(imageKey, srcImageStm, m_imageFormats, this, context);
 
             if (null != requestFormat) {
-                ret = job.processRequestFormat(requestFormat);
+                errorOccured = (null == (ret = job.processRequestFormat(requestFormat)));
             }
 
-            // add job to appropriate queue
-            implAdd(job, (null != priority) ? priority : ImageConverterPriority.BACKGROUND);
-
-            // Runnable was put into queue, set flag to not close job and start processing
-            ElementLocker.unlock(imageKey, ElementLock.UnlockMode.STANDARD);
+            // add job to appropriate queue for asynchronous
+            // processing, if everything went well so far
+            if (!errorOccured) {
+                implAdd(job, (null != priority) ? priority : ImageConverterPriority.BACKGROUND);
+            }
         } catch (ImageConverterException e) {
-            implCloseJob(job, true);
-            ElementLocker.unlock(imageKey, ElementLock.UnlockMode.END_PROCESSING);
-
-            // Resource warning has been checked:
-            // job has been closed already before
+            // job is closed in finally block
+            errorOccured = true;
             throw e;
+        } finally {
+            if (errorOccured) {
+                // close job in case of error =>
+                // the imageKey will be removed from processingMap as well
+                if (null != job) {
+                    implCloseJob(job, true);
+                }
+
+                LOG.warn("IC removed entry after occurence of an error: {}", imageKey);
+            }
+
+            // unlock image key with unlock mode based on error status
+            ElementLocker.unlock(imageKey,
+                errorOccured ?
+                    ElementLock.UnlockMode.END_PROCESSING :
+                        ElementLock.UnlockMode.STANDARD);
         }
 
         // Resource warning has been checked:
@@ -747,7 +784,13 @@ class ImageConverterQueue extends Thread {
         } catch (FileItemException e) {
             LOG.trace("IC error while removing imageKey when closing Runnable: {}", imageKey, e);
         } finally {
+            // close job itself
             IOUtils.closeQuietly(job);
+
+            // remove imageKey from processing map
+            if (null != imageKey) {
+                m_processingMap.remove(imageKey);
+            }
         }
 
         LOG.trace("IC queue closed job: {}", imageKey);
@@ -874,7 +917,8 @@ class ImageConverterQueue extends Thread {
                     if ((null != (curJob = iter.next())) && imageKey.equals(curJob.getImageKey())) {
                         if (endProcessing) {
                             iter.remove();
-                            m_processingMap.remove(imageKey);
+
+                            // close job, imageKey will be removed from processingMap as well
                             implCloseJob(curJob, false);
                         }
 
